@@ -13,10 +13,10 @@ utils::globalVariables(c(".", "%>%", ":="))
 #' @importFrom data.table := %between% fifelse %chin%
 #' @importFrom stats na.omit
 #' @importFrom utils head tail object.size
-#' @importFrom stats na.omit
 #' @importFrom Rcpp compileAttributes
 #' @importFrom lwgeom st_geod_length
 #' @importFrom rgdal readOGR
+#' @importFrom readr write_rds
 #' @useDynLib gtfs2gps, .registration = TRUE
 NULL
 
@@ -30,4 +30,5 @@ if(getRversion() >= "2.15.1") utils::globalVariables(
     'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday',
     'service_duration', 'headway_secs', 'number_of_departures',
     'cumtime', 'speed', 'i', 'route_type', 'trip_number', 'mdate',
-    '.I', 'interval_id', 'i.interval', '.SD', 'grp', '.GRP'))
+    '.I', 'interval_id', 'i.interval', '.SD', 'grp', '.GRP',
+    'start_trip_number','end_trip_number'))
