@@ -5,7 +5,7 @@
 library("gtfs2gps")
 sao <- read_gtfs(system.file("extdata/saopaulo.zip", package ="gtfs2gps"))
 names(sao)
-sao$trips
+head(sao$trips)
 
 ## -----------------------------------------------------------------------------
 library(magrittr)
