@@ -13,11 +13,11 @@ test_that("snap_points", {
   shape_points <- sf::st_as_sf(shape_points, coords = c('X', 'Y'), agr = "identity", crs = 31982)
 
   res <- 15
-  result <- cpp_snap_points(stops %>% sf::st_coordinates(), stops %>% sf::st_coordinates(), res)
+  result <- cpp_snap_points_nearest1(stops %>% sf::st_coordinates(), stops %>% sf::st_coordinates(), res)
   
   expect_equal(result, 1)
 
-  expect_length(cpp_snap_points(stops %>% sf::st_coordinates(), matrix(2, 1), res), 0)
+  expect_length(cpp_snap_points_nearest1(stops %>% sf::st_coordinates(), matrix(2, 1), res), 0)
 
   # complete test
   gtfs <- read_gtfs(system.file("extdata/poa.zip", package="gtfs2gps")) %>%
@@ -31,7 +31,7 @@ test_that("snap_points", {
   shape_points <- sf::st_as_sf(shape_points, coords = c('X', 'Y'), agr="identity", crs = 31982)
   
   res <- 3000
-  result <- cpp_snap_points(stops %>% sf::st_coordinates(), shape_points %>% sf::st_coordinates(), res)
+  result <- cpp_snap_points_nearest2(stops %>% sf::st_coordinates(), shape_points %>% sf::st_coordinates(), res)
   
   expect_equal(length(result), 0)
   expect_true(all(result == sort(result)))
